# Pubword

This is a collection of 19,000 unique words scraped from publically available PubMed abstracts. 

# INFORMATION
1. This repository contains 19,000 unique words which have mostly been cleaned -- spot check as needed.
2. This repository contains words in `lower case` only, at this time. 

# HOW TO USE
1. Install
`pip install pubwords`
2. Import
`from pubwords.words import word_list`
3. Get the word list
`your_variable = word_list`
